require 'spec_helper'

describe Html2erb do
  it 'should have a version number' do
    Html2erb::VERSION.should_not be_nil
  end

  describe 'create erb file' do
    before do
      @html = 'spec/test.html'
      @erb  = 'spec/test.html.erb'
      File.delete @erb if File.exists? @erb

      html_to_erb = Html2erb.new(
        replace_map: [
          [/<html.*id="main">/m, '<% content_for :title do %><% end %>'],
          [/<\/div>\n  <section class="footer">.*/m, '']
        ]
      )
      html_to_erb.run(@html)
    end

    it 'erb file exists' do
      File.exists?(@erb).should be_true
    end

    it 'remove header and footer' do
      open(@erb, "r+") do |f|
        html = f.read
        html.include?('header').should be_false
        html.include?('footer').should be_false
      end
    end

    it 'replace a-tag to link_to' do
      open(@erb, "r+") do |f|
        html = f.read
        html.include?('link_to').should be_true
        html.include?(
            %{<%= link_to(image_tag("google.jpg", title: 'foo') + content_tag(:span, "span", class: 'span-class'), "http://google.com", class: 'foo', alt: 'グーグル') %>}
        ).should be_true
      end
    end

    it 'replace image-tag to image' do
      open(@erb, "r+") do |f|
        html = f.read
        html.include?(%{<%= image_tag("foo.jpg", title: 'foo') %>}).should be_true
      end
    end


    after do
      File.delete @erb if File.exists? @erb
    end
  end
end
